package com.example.collectionofshortstories.view.catalog

import android.util.Log
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box

import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.Button

import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.key
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavHostController
import com.example.collectionofshortstories.domain.untils.Constants
import com.example.collectionofshortstories.model.Categories
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext

@Composable
fun Catalog(navHostController: NavHostController) {
    val viewModel = CatalogViewModel()


    val articles by viewModel.articles.collectAsState(initial = emptyList())
    val user_role by viewModel.role_name.collectAsState(initial = "")

    LaunchedEffect(Unit) {
        viewModel.GetArticles()
        viewModel.GetUserRole()
    }

    // Кэширование значения для отображения кнопки
    val showButton = remember(user_role) { user_role == "Писатель" }

    Box() {
        LazyColumn(
            modifier = Modifier
                .fillMaxSize() // Занимает весь экран
                .padding(16.dp) // Добавлен отступ для LazyColumn
        ) {
            items(
                articles,
                key = { articleDate -> articleDate.id }
            ) { articleDate ->
                Row(
                    horizontalArrangement = Arrangement.SpaceAround,
                    modifier = Modifier
                        .fillMaxWidth()
                ) {
                    Text(
                        text = articleDate.title,
                        modifier = Modifier
                            .padding(30.dp)
                            .weight(1f)
                    )
                }
            }
        }
        if (showButton) {
            Button(
                onClick = { /* Действия при нажатии на кнопку */ },
                modifier = Modifier
                    .align(Alignment.BottomEnd)
                    .padding(0.dp, 0.dp, 40.dp, 80.dp)
            ) {
                Text("Добавить рассказ")
            }
        }
    }
}